Skip to contents

Renders manimR scenes to raster (PNG) frames using the ragg backend. Supports VMobject Bezier paths with fill and stroke, submobject recursion, text, images, and the full R6 Animation system.

Super class

manimR::AbstractRenderer -> AggRenderer

Methods

Inherited methods


Method new()

Create AggRenderer

Usage

AggRenderer$new(...)

Arguments

...

Arguments passed to AbstractRenderer


Method begin_frame()

Begin a new frame using ragg

Usage

AggRenderer$begin_frame(output_path = NULL)

Arguments

output_path

Path to save PNG file


Method end_frame()

End the current frame

Usage

AggRenderer$end_frame()


Method draw_path()

Draw a path (polygon/polyline) with fill and stroke

Usage

AggRenderer$draw_path(
  x,
  y,
  fill_color = NULL,
  fill_opacity = 0,
  stroke_color = "#FFFFFF",
  stroke_opacity = 1,
  stroke_width = 2
)


Method draw_text()

Draw text

Usage

AggRenderer$draw_text(
  text,
  x,
  y,
  color = "#FFFFFF",
  font_size = 24,
  font_family = "sans",
  opacity = 1
)


Method draw_raster()

Draw a raster image

Usage

AggRenderer$draw_raster(raster, xleft, ybottom, xright, ytop, opacity = 1)


Method draw_image_state()

Draw image from state dict (ragg-specific with magick)

Usage

AggRenderer$draw_image_state(state)


Method clone()

The objects of this class are cloneable with this method.

Usage

AggRenderer$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.