Skip to contents

An angle arc between two lines meeting at a common point.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Arc -> Angle

Public fields

line1

First line/vector

line2

Second line/vector

dot

Whether to show a dot for small angles

dot_radius

Radius of the angle dot

elbow

Whether to draw a right-angle elbow

Methods

Inherited methods


Method new()

Create a new Angle indicator

Usage

Angle$new(
  line1 = NULL,
  line2 = NULL,
  radius = 0.5,
  quadrant = c(1, 1),
  other_angle = FALSE,
  dot = FALSE,
  dot_radius = DEFAULT_DOT_RADIUS,
  elbow = FALSE,
  color = WHITE,
  ...
)

Arguments

line1

First Line object or direction vector

line2

Second Line object or direction vector

radius

Radius of the angle arc

quadrant

Which quadrant to draw the angle in (c(1,1) default)

other_angle

Whether to show the reflex angle

dot

Show a dot in the angle

dot_radius

Dot radius

elbow

Draw right-angle elbow instead of arc

color

Color

...

Additional args


Method get_value()

Get the value of the angle in radians

Usage

Angle$get_value()


Method get_value_degrees()

Get the value of the angle in degrees

Usage

Angle$get_value_degrees()


Method clone()

The objects of this class are cloneable with this method.

Usage

Angle$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.