Skip to contents

Animates the result of calling a method on a mobject. Creates a copy, applies the method, then morphs to the result.

Super classes

manimR::Animation -> manimR::Transform -> ApplyMethod

Methods

Inherited methods


Method new()

Create an ApplyMethod animation

Usage

ApplyMethod$new(mobject, method_name, ..., run_time = 1, rate_func = "smooth")

Arguments

mobject

The mobject

method_name

Name of the method to call

...

Arguments to the method

run_time

Duration

rate_func

Easing


Method clone()

The objects of this class are cloneable with this method.

Usage

ApplyMethod$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.