Skip to contents

Applies a wave deformation that passes through the mobject.

Super class

manimR::Animation -> ApplyWave

Public fields

direction

Direction of the wave displacement

amplitude

Wave amplitude

wave_length

Wavelength as proportion of mobject width

Methods

Inherited methods


Method new()

Create an ApplyWave animation

Usage

ApplyWave$new(
  mobject,
  direction = UP,
  amplitude = 0.2,
  wave_length = 1,
  run_time = 2,
  rate_func = "linear",
  ...
)

Arguments

mobject

VMobject to deform

direction

Direction of displacement

amplitude

Wave height

wave_length

Relative wavelength

run_time

Duration

rate_func

Easing

...

Additional args


Method interpolate_mobject()

Apply travelling wave to points

Usage

ApplyWave$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

ApplyWave$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.