Skip to contents

An arc passing through two points with a given curvature.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Arc -> ArcBetweenPoints

Methods

Inherited methods


Method new()

Create an arc between two points

Usage

ArcBetweenPoints$new(
  start = c(-1, 0, 0),
  end = c(1, 0, 0),
  angle = pi/2,
  color = WHITE,
  ...
)

Arguments

start

Start point

end

End point

angle

Arc sweep angle (PI/2 = quarter circle)

color

Color

...

Additional args


Method clone()

The objects of this class are cloneable with this method.

Usage

ArcBetweenPoints$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.