Skip to contents

A line with an arrowhead tip at the end.

A line with a tip at the end.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Line -> Arrow

Public fields

tip_length

Arrow tip length

tip

The ArrowTip submobject

Active bindings

tip

The ArrowTip submobject

Methods

Inherited methods


Method new()

Usage

Arrow$new(start = c(-1, 0, 0), end = c(1, 0, 0), tip_length = 0.2, ...)


Method add_tip()

Usage

Arrow$add_tip(tip_pos, tail_pos)


Method clone()

The objects of this class are cloneable with this method.

Usage

Arrow$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Line -> Arrow

Methods

Inherited methods


Method new()

Usage

Arrow$new(start = c(-1, 0, 0), end = c(1, 0, 0), tip_length = 0.2, ...)


Method add_tip()

Usage

Arrow$add_tip(tip_pos, tail_pos)


Method clone()

The objects of this class are cloneable with this method.

Usage

Arrow$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.