Skip to contents

A vertically arranged list of Text items with bullet markers.

Super classes

manimR::MObject -> manimR::VMobject -> BulletedList

Public fields

items

Character vector of list items

bullet

Character used as bullet

Methods

Inherited methods


Method new()

Create a BulletedList

Usage

BulletedList$new(
  ...,
  font_size = DEFAULT_FONT_SIZE,
  color = WHITE,
  buff = MED_LARGE_BUFF,
  bullet = "•"
)

Arguments

...

Text strings for each bullet item

font_size

Font size

color

Color

buff

Vertical spacing between items

bullet

Bullet character


Method fade_in_sequentially()

Fade in items one by one (returns list of FadeIn animations)

Usage

BulletedList$fade_in_sequentially()


Method clone()

The objects of this class are cloneable with this method.

Usage

BulletedList$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.