Skip to contents

A full circle using 4-segment cubic Bezier approximation.

A circular VMobject.

Super classes

manimR::MObject -> manimR::VMobject -> Circle

Methods

Inherited methods


Method new()

Usage

Circle$new(radius = 1, color = "#FFFFFF", ...)


Method generate_points()

Usage

Circle$generate_points()


Method clone()

The objects of this class are cloneable with this method.

Usage

Circle$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

manimR::MObject -> manimR::VMobject -> Circle

Methods

Inherited methods


Method new()

Usage

Circle$new(radius = 1, color = "#FFFFFF", ...)


Method generate_points()

Usage

Circle$generate_points()


Method clone()

The objects of this class are cloneable with this method.

Usage

Circle$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.