Skip to contents

A cone with a circular base and apex at the top.

Public fields

base_radius

Base circle radius

height

Cone height

Methods

Public methods

Inherited methods


Method new()

Create a Cone

Usage

Cone$new(
  base_radius = 1,
  height = 2,
  u_resolution = 32,
  v_resolution = 8,
  color = GOLD_D,
  ...
)

Arguments

base_radius

Base radius

height

Cone height

u_resolution

Angular subdivisions

v_resolution

Height subdivisions

color

Surface color

...

Additional args


Method clone()

The objects of this class are cloneable with this method.

Usage

Cone$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.