Skip to contents

Draws a VMobject by progressively revealing its strokes, then filling it in. The canonical "write-on" effect.

Super class

manimR::Animation -> Create

Methods

Inherited methods


Method new()

Create a Create animation

Usage

Create$new(mobject, run_time = 2, rate_func = "smooth", ...)

Arguments

mobject

VMobject to create

run_time

Duration

rate_func

Easing function

...

Additional args


Method begin()

Save starting state

Usage

Create$begin()


Method interpolate_mobject()

Progressive reveal of stroke then fill

Usage

Create$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method finish()

Ensure final state is correct

Usage

Create$finish()


Method clone()

The objects of this class are cloneable with this method.

Usage

Create$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.