Skip to contents

A directed graph with Arrow edges instead of Lines.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Graph -> DiGraph

Methods

Inherited methods


Method new()

Create a directed Graph

Usage

DiGraph$new(vertices, edges, layout = "spring", ...)

Arguments

vertices

Vertex ids

edges

Directed edges (list of c(from, to))

layout

Layout algorithm

...

Additional args


Method to_igraph()

Convert to igraph object (directed)

Usage

DiGraph$to_igraph()


Method clone()

The objects of this class are cloneable with this method.

Usage

DiGraph$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.