Skip to contents

The difference (A - B) of two VMobject shapes. Produces the area of shape A not covered by shape B. Requires the polyclip package.

Super classes

manimR::MObject -> manimR::VMobject -> Difference

Methods

Inherited methods


Method new()

Create a difference of two shapes

Usage

Difference$new(
  vmobject1,
  vmobject2,
  color = WHITE,
  fill_color = NULL,
  fill_opacity = 0.5,
  precision = 30,
  ...
)

Arguments

vmobject1

First VMobject (A)

vmobject2

Second VMobject (B, subtracted from A)

color

Stroke color

fill_color

Fill color

fill_opacity

Fill opacity

precision

Bezier sampling precision

...

Additional args


Method clone()

The objects of this class are cloneable with this method.

Usage

Difference$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.