Skip to contents

A small filled circle (point).

A solid dot (small circle).

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Circle -> Dot

Methods

Public methods

Inherited methods


Method new()

Usage

Dot$new(point = c(0, 0, 0), radius = 0.08, color = "#FFFFFF", ...)


Method clone()

The objects of this class are cloneable with this method.

Usage

Dot$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Circle -> Dot

Methods

Public methods

Inherited methods


Method new()

Usage

Dot$new(point = c(0, 0, 0), radius = 0.08, color = "#FFFFFF", ...)


Method clone()

The objects of this class are cloneable with this method.

Usage

Dot$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.