Skip to contents

Fades a mobject in from transparent, optionally sliding from a direction.

Super class

manimR::Animation -> FadeIn

Public fields

shift_vector

Direction to fade in from

scale_factor

Initial scale (for zoom-in effect)

target_position

Saved target position

Methods

Inherited methods


Method new()

Create a FadeIn animation

Usage

FadeIn$new(
  mobject,
  shift = NULL,
  scale = 1,
  run_time = 1,
  rate_func = "smooth",
  ...
)

Arguments

mobject

Mobject to fade in

shift

Direction to slide from (NULL = fade in place)

scale

Starting scale factor (< 1 = grow in, > 1 = shrink in)

run_time

Duration

rate_func

Easing

...

Additional args


Method begin()

Save target state and set initial transparent state

Usage

FadeIn$begin()


Method interpolate_mobject()

Interpolate opacity and position

Usage

FadeIn$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method finish()

Ensure final state

Usage

FadeIn$finish()


Method clone()

The objects of this class are cloneable with this method.

Usage

FadeIn$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.