Skip to contents

Fades a mobject out to transparent, optionally sliding towards a direction.

Super class

manimR::Animation -> FadeOut

Public fields

shift_vector

Direction to fade out towards

target_scale

Final scale factor

Methods

Inherited methods


Method new()

Create a FadeOut animation

Usage

FadeOut$new(
  mobject,
  shift = NULL,
  scale = 1,
  run_time = 1,
  rate_func = "smooth",
  ...
)

Arguments

mobject

Mobject to fade out

shift

Direction to slide towards (NULL = fade in place)

scale

Ending scale factor

run_time

Duration

rate_func

Easing

...

Additional args


Method begin()

Save starting state

Usage

FadeOut$begin()


Method interpolate_mobject()

Interpolate opacity and position

Usage

FadeOut$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

FadeOut$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.