Skip to contents

Draws a shrinking circle to focus attention on a point.

Super class

manimR::Animation -> FocusOn

Public fields

point

Focus point

focus_color

Color of the focus circle

Methods

Inherited methods


Method new()

Create a FocusOn animation

Usage

FocusOn$new(
  point = ORIGIN,
  color = GREY,
  run_time = 0.5,
  rate_func = "smooth",
  ...
)

Arguments

point

Point or mobject to focus on

color

Circle color

run_time

Duration

rate_func

Easing

...

Additional args


Method interpolate_mobject()

Shrink circle to point

Usage

FocusOn$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

FocusOn$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.