Skip to contents

Grows an Arrow from its start point to its end.

Super class

manimR::Animation -> GrowArrow

Methods

Inherited methods


Method new()

Create a GrowArrow animation

Usage

GrowArrow$new(arrow, run_time = 1, rate_func = "smooth", ...)

Arguments

arrow

An Arrow mobject

run_time

Duration

rate_func

Easing

...

Additional args


Method begin()

Save the arrow state

Usage

GrowArrow$begin()


Method interpolate_mobject()

Progressively reveal the arrow

Usage

GrowArrow$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

GrowArrow$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.