Skip to contents

Grows a mobject from a single point at its center.

Super class

manimR::Animation -> GrowFromCenter

Methods

Inherited methods


Method new()

Create a GrowFromCenter animation

Usage

GrowFromCenter$new(mobject, run_time = 1, rate_func = "smooth", ...)

Arguments

mobject

Mobject to grow

run_time

Duration

rate_func

Easing

...

Additional args


Method begin()

Begin: save target state, collapse to center

Usage

GrowFromCenter$begin()


Method interpolate_mobject()

Grow from zero scale to full

Usage

GrowFromCenter$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

GrowFromCenter$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.