Skip to contents

A convenience table for displaying integer matrices, useful for demonstrating matrix operations and linear algebra.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Table -> IntegerTable

Methods

Inherited methods


Method new()

Create an IntegerTable from a numeric matrix

Usage

IntegerTable$new(mat, ...)

Arguments

mat

Numeric matrix

...

Arguments passed to Table


Method clone()

The objects of this class are cloneable with this method.

Usage

IntegerTable$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.