Skip to contents

Applies the same animation constructor to each element of a VGroup/list with a stagger.

Super classes

manimR::Animation -> manimR::AnimationGroup -> LaggedStartMap

Methods

Inherited methods


Method new()

Create a LaggedStartMap

Usage

LaggedStartMap$new(
  anim_class,
  mobjects,
  lag_ratio = 0.5,
  run_time = NULL,
  rate_func = "linear",
  ...
)

Arguments

anim_class

Animation class (e.g., FadeIn)

mobjects

List of mobjects or a VGroup

lag_ratio

Stagger ratio

run_time

Override total run time

rate_func

Rate function

...

Additional args passed to each animation constructor


Method clone()

The objects of this class are cloneable with this method.

Usage

LaggedStartMap$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.