Skip to contents

A straight line between two points.

A straight line between two points.

Super classes

manimR::MObject -> manimR::VMobject -> Line

Methods

Public methods

Inherited methods


Method new()

Usage

Line$new(
  start = c(-1, 0, 0),
  end = c(1, 0, 0),
  color = "#FFFFFF",
  stroke_width = 2,
  ...
)


Method clone()

The objects of this class are cloneable with this method.

Usage

Line$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

manimR::MObject -> manimR::VMobject -> Line

Methods

Public methods

Inherited methods


Method new()

Usage

Line$new(
  start = c(-1, 0, 0),
  end = c(1, 0, 0),
  color = "#FFFFFF",
  stroke_width = 2,
  ...
)


Method clone()

The objects of this class are cloneable with this method.

Usage

Line$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.