Skip to contents

Text with Pango-style markup support. Allows inline bold, italic, color, and size changes using a simple tag syntax.

Details

Supported tags:

  • <b>bold</b>

  • <i>italic</i>

  • <color hex="#FF0000">red text</color>

  • <size val="72">big text</size>

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Text -> MarkupText

Public fields

original_text

The raw markup string

Methods

Inherited methods


Method new()

Create MarkupText

Usage

MarkupText$new(text, ...)

Arguments

text

Markup text string

...

Arguments passed to Text


Method clone()

The objects of this class are cloneable with this method.

Usage

MarkupText$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.