Skip to contents

A matrix displayed with brackets, as commonly seen in linear algebra. Wraps a Table with bracket decorations.

Super classes

manimR::MObject -> manimR::VMobject -> MatrixMobject

Public fields

mat

The numeric matrix

table_mob

The inner Table

left_bracket

Left bracket VMobject

right_bracket

Right bracket VMobject

bracket_type

Bracket style ("square", "round", "curly")

Methods

Inherited methods


Method new()

Create a MatrixMobject

Usage

MatrixMobject$new(
  mat,
  bracket_type = "square",
  font_size = 30,
  color = WHITE,
  ...
)

Arguments

mat

Numeric matrix

bracket_type

"square", "round", or "curly"

font_size

Cell font size

color

Text color

...

Additional args


Method get_entry()

Get entry at (i, j) as a mobject

Usage

MatrixMobject$get_entry(i, j)

Arguments

i

Row index

j

Column index


Method get_row()

Get row as VGroup

Usage

MatrixMobject$get_row(i)

Arguments

i

Row index


Method get_col()

Get column as VGroup

Usage

MatrixMobject$get_col(j)

Arguments

j

Column index


Method clone()

The objects of this class are cloneable with this method.

Usage

MatrixMobject$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.