Skip to contents

Animation created by AnimationBuilder that interpolates a mobject from its current state to a target state.

Super class

manimR::Animation -> MethodAnimation

Public fields

target

The target state

Methods

Inherited methods


Method new()

Create a MethodAnimation

Usage

MethodAnimation$new(mobject, target, run_time = 1, rate_func = "smooth")

Arguments

mobject

Current mobject

target

Target state (copy with methods applied)

run_time

Duration

rate_func

Easing


Method interpolate_mobject()

Interpolate between starting state and target

Usage

MethodAnimation$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

MethodAnimation$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.