Skip to contents

Moves a mobject along the path of another VMobject.

Super class

manimR::Animation -> MoveAlongPath

Public fields

path

The VMobject whose Bezier path to follow

Methods

Inherited methods


Method new()

Create a MoveAlongPath animation

Usage

MoveAlongPath$new(mobject, path, run_time = 2, rate_func = "linear", ...)

Arguments

mobject

Mobject to move

path

VMobject defining the path

run_time

Duration

rate_func

Easing

...

Additional args


Method interpolate_mobject()

Move along the path

Usage

MoveAlongPath$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

MoveAlongPath$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.