Skip to contents

A Camera that can be animated. Provides the frame object (a VMobject rectangle representing the camera's field of view) which can be animated with standard Transform/ApplyMethod animations.

Super class

manimR::Camera -> MovingCamera

Public fields

frame

A Rectangle VMobject representing the camera view

Methods

Inherited methods


Method new()

Create a MovingCamera

Usage

MovingCamera$new(...)

Arguments

...

Passed to Camera$new()


Method sync_from_frame()

Sync camera state from the frame mobject Call this after animating the frame to update the camera.

Usage

MovingCamera$sync_from_frame()


Method move_to()

Override move_to to also update frame

Usage

MovingCamera$move_to(point)

Arguments

point

Target position


Method shift()

Override shift to also update frame

Usage

MovingCamera$shift(direction)

Arguments

direction

Shift vector


Method set_zoom()

Override set_zoom to also scale frame

Usage

MovingCamera$set_zoom(zoom)

Arguments

zoom

Zoom factor


Method clone()

The objects of this class are cloneable with this method.

Usage

MovingCamera$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.