Skip to contents

A 2D coordinate plane with background grid lines. Each grid line is a VMobject submobject, allowing individual animation. Grid lines can optionally fade by distance from axes.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Axes -> NumberPlane

Public fields

background_lines

VGroup of background grid lines

faded_lines

Number of fading levels (0 = no fading)

background_line_color

Color for grid lines

background_line_width

Width of background grid lines

background_line_opacity

Opacity of background grid lines

Methods

Inherited methods


Method new()

Create a NumberPlane

Usage

NumberPlane$new(
  x_range = c(-10, 10, 1),
  y_range = c(-6, 6, 1),
  x_length = 10 * FRAME_X_RADIUS/5,
  y_length = 6 * FRAME_Y_RADIUS/3,
  background_line_color = BLUE_D,
  background_line_width = 1,
  background_line_opacity = 0.5,
  faded_lines = 1,
  ...
)

Arguments

x_range

c(min, max, step)

y_range

c(min, max, step)

x_length

Width in scene units

y_length

Height in scene units

background_line_color

Color for grid lines

background_line_width

Width of grid lines

background_line_opacity

Opacity of grid lines

faded_lines

Number of fading sub-divisions (0=none)

...

Additional args passed to Axes


Method get_background_lines()

Get all background grid lines as a VGroup

Usage

NumberPlane$get_background_lines()


Method prepare_for_field()

Prepare the plane for a phase portrait or vector field display

Usage

NumberPlane$prepare_for_field(line_opacity = 0.3)

Arguments

line_opacity

Opacity for grid lines


Method clone()

The objects of this class are cloneable with this method.

Usage

NumberPlane$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.