Skip to contents

Moves a mobject according to a velocity field over time.

Super class

manimR::Animation -> PhaseFlow

Public fields

velocity_func

Function(point) -> velocity vector

virtual_time

Total virtual time to simulate

Methods

Inherited methods


Method new()

Create a PhaseFlow animation

Usage

PhaseFlow$new(
  mobject,
  velocity_func,
  virtual_time = 1,
  run_time = 3,
  rate_func = "linear",
  ...
)

Arguments

mobject

Mobject to move

velocity_func

Function(point) -> c(vx, vy, vz) velocity

virtual_time

How much "physics time" to simulate

run_time

Animation duration

rate_func

Easing

...

Additional args


Method begin()

Begin: save starting state

Usage

PhaseFlow$begin()


Method interpolate_mobject()

Euler integration of velocity field

Usage

PhaseFlow$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

PhaseFlow$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.