Skip to contents

A polar coordinate system with radial and angular grid lines.

Super classes

manimR::MObject -> manimR::VMobject -> PolarPlane

Public fields

radius_max

Maximum radius

radius_step

Step between radial grid lines

azimuth_step

Angular step in radians for grid lines

size

Scene size of the full plot

Methods

Inherited methods


Method new()

Create a PolarPlane

Usage

PolarPlane$new(
  radius_max = 3,
  radius_step = 1,
  azimuth_step = PI/6,
  size = 6,
  color = GREY_B,
  ...
)

Arguments

radius_max

Maximum radius value

radius_step

Step for radial circles

azimuth_step

Angular step (default PI/6 = 30 degrees)

size

Diameter in scene units

color

Grid color

...

Additional args


Method pr2p()

Polar to Point: (r, theta) -> scene (x, y, z)

Usage

PolarPlane$pr2p(r, theta)

Arguments

r

Radius

theta

Angle in radians


Method p2pr()

Point to Polar: scene (x, y) -> (r, theta)

Usage

PolarPlane$p2pr(point)

Arguments

point

Scene coordinate


Method clone()

The objects of this class are cloneable with this method.

Usage

PolarPlane$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.