Skip to contents

A rectangle with given width and height.

A simple rectangle.

Super classes

manimR::MObject -> manimR::VMobject -> Rectangle

Public fields

width

Rectangle width

height

Rectangle height

Methods

Inherited methods


Method new()

Usage

Rectangle$new(width = 4, height = 2, color = "#FFFFFF", ...)


Method generate_points()

Usage

Rectangle$generate_points()


Method clone()

The objects of this class are cloneable with this method.

Usage

Rectangle$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

manimR::MObject -> manimR::VMobject -> Rectangle

Methods

Inherited methods


Method new()

Usage

Rectangle$new(width = 4, height = 2, color = "#FFFFFF", ...)


Method generate_points()

Usage

Rectangle$generate_points()


Method clone()

The objects of this class are cloneable with this method.

Usage

Rectangle$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.