Skip to contents

Like Transform, but the original mobject is removed from the scene and the target is added. The target gets the interpolated state during animation.

Super classes

manimR::Animation -> manimR::Transform -> ReplacementTransform

Methods

Inherited methods


Method new()

Create a ReplacementTransform

Usage

ReplacementTransform$new(
  mobject,
  target_mobject,
  run_time = 1,
  rate_func = "smooth",
  ...
)

Arguments

mobject

Source mobject (will be removed)

target_mobject

Target mobject (will be added)

run_time

Duration

rate_func

Easing

...

Additional args


Method finish()

After animation, ensure target has its final state

Usage

ReplacementTransform$finish()


Method clone()

The objects of this class are cloneable with this method.

Usage

ReplacementTransform$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.