Skip to contents

A brief flash that travels along the path of a VMobject.

Super class

manimR::Animation -> ShowPassingFlash

Public fields

time_width

Width of the flash as proportion of path

Methods

Inherited methods


Method new()

Create a ShowPassingFlash animation

Usage

ShowPassingFlash$new(
  mobject,
  time_width = 0.3,
  run_time = 1,
  rate_func = "linear",
  ...
)

Arguments

mobject

VMobject whose path the flash follows

time_width

Width of flash (0-1)

run_time

Duration

rate_func

Easing

...

Additional args


Method begin()

Save starting state

Usage

ShowPassingFlash$begin()


Method interpolate_mobject()

Show flash travelling along path

Usage

ShowPassingFlash$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method finish()

Restore original opacity

Usage

ShowPassingFlash$finish()


Method clone()

The objects of this class are cloneable with this method.

Usage

ShowPassingFlash$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.