Skip to contents

A UV-mapped sphere of given radius, centered at the origin.

Public fields

radius

Sphere radius

Methods

Public methods

Inherited methods


Method new()

Create a Sphere

Usage

Sphere$new(
  radius = 1,
  u_resolution = 32,
  v_resolution = 24,
  color = BLUE_D,
  ...
)

Arguments

radius

Sphere radius

u_resolution

Longitude subdivisions

v_resolution

Latitude subdivisions

color

Surface color

...

Additional args passed to Surface


Method clone()

The objects of this class are cloneable with this method.

Usage

Sphere$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.