Skip to contents

A square (rectangle with equal sides).

A square.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Rectangle -> Square

Public fields

side_length

Side length

Methods

Public methods

Inherited methods


Method new()

Usage

Square$new(side_length = 2, ...)


Method clone()

The objects of this class are cloneable with this method.

Usage

Square$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Rectangle -> Square

Methods

Public methods

Inherited methods


Method new()

Usage

Square$new(side_length = 2, ...)


Method clone()

The objects of this class are cloneable with this method.

Usage

Square$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.