Skip to contents

A star polygon with alternating outer and inner vertices.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Polygon -> Star

Public fields

n

Number of points

outer_radius

Outer radius

inner_radius

Inner radius

Methods

Public methods

Inherited methods


Method new()

Create a new Star

Usage

Star$new(
  n = 5,
  outer_radius = 1,
  inner_radius = NULL,
  color = WHITE,
  fill_color = NULL,
  fill_opacity = 0,
  ...
)

Arguments

n

Number of points

outer_radius

Outer radius

inner_radius

Inner radius (default: outer_radius / 2)

color

Color

fill_color

Fill color

fill_opacity

Fill opacity

...

Additional args


Method clone()

The objects of this class are cloneable with this method.

Usage

Star$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.