Skip to contents

A scene pre-configured for statistical visualizations with helper methods for common statistical animations.

Super class

manimR::Scene -> StatScene

Public fields

axes

Default axes for the scene

Methods

Inherited methods


Method new()

Create a StatScene

Usage

StatScene$new(
  name = "stat_scene",
  x_range = c(-5, 5, 1),
  y_range = c(0, 5, 1),
  ...
)

Arguments

name

Scene name

x_range

X range

y_range

Y range

...

Additional args


Method add_histogram()

Quick histogram animation

Usage

StatScene$add_histogram(data, bins = 30, color = BLUE)

Arguments

data

Numeric vector

bins

Number of bins

color

Bar color


Method add_regression()

Quick regression animation

Usage

StatScene$add_regression(data, x, y)

Arguments

data

Data.frame

x

X column

y

Y column


Method clone()

The objects of this class are cloneable with this method.

Usage

StatScene$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.