Skip to contents

A 3D coordinate system with x, y, and z axes. Extends Axes with a z-axis and 3D coordinate mapping.

3D Axes.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Axes -> ThreeDAxes

Public fields

z_range

c(min, max, step) for z-axis

z_length

Length of z-axis in scene units

Methods

Inherited methods


Method new()

Usage

ThreeDAxes$new(
  x_range = c(-5, 5, 1),
  y_range = c(-5, 5, 1),
  z_range = c(-3, 3, 1),
  x_length = 10,
  y_length = 10,
  z_length = 6,
  ...
)


Method create_axes()

Usage

ThreeDAxes$create_axes()


Method c2p()

Usage

ThreeDAxes$c2p(x, y, z = 0)


Method clone()

The objects of this class are cloneable with this method.

Usage

ThreeDAxes$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Axes -> ThreeDAxes

Methods

Inherited methods


Method new()

Usage

ThreeDAxes$new(
  x_range = c(-5, 5, 1),
  y_range = c(-5, 5, 1),
  z_range = c(-3, 3, 1),
  x_length = 10,
  y_length = 10,
  z_length = 6,
  ...
)


Method create_axes()

Usage

ThreeDAxes$create_axes()


Method c2p()

Usage

ThreeDAxes$c2p(x, y, z = 0)


Method clone()

The objects of this class are cloneable with this method.

Usage

ThreeDAxes$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.