Skip to contents

A scene pre-configured for 3D rendering with a ThreeDCamera. Provides convenience methods for setting camera angles and ambient lighting.

Super class

manimR::Scene -> ThreeDScene

Public fields

camera3d

ThreeDCamera instance

Methods

Inherited methods


Method new()

Create a ThreeDScene

Usage

ThreeDScene$new(name = "3d_scene", phi = PI/4, theta = -PI/4, gamma = 0, ...)

Arguments

name

Scene name

phi

Initial azimuth angle

theta

Initial elevation angle

gamma

Roll angle

...

Additional args passed to Scene


Method set_camera_orientation()

Set camera orientation

Usage

ThreeDScene$set_camera_orientation(phi = NULL, theta = NULL, gamma = NULL)

Arguments

phi

Azimuth angle

theta

Elevation angle

gamma

Roll angle


Method begin_ambient_rotation()

Begin ambient rotation of the camera

Usage

ThreeDScene$begin_ambient_rotation(rate = 0.1, about = "theta")

Arguments

rate

Rotation rate in radians per second

about

Which axis to rotate about ("theta" or "phi")


Method stop_ambient_rotation()

Stop ambient rotation

Usage

ThreeDScene$stop_ambient_rotation()


Method add_axes()

Add 3D axes to the scene

Usage

ThreeDScene$add_axes(...)

Arguments

...

Arguments passed to ThreeDAxes


Method clone()

The objects of this class are cloneable with this method.

Usage

ThreeDScene$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.