Skip to contents

A large, centered title text. Convenience wrapper around Text with increased font_size and bold weight positioned at the top of the screen.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Text -> Title

Methods

Public methods

Inherited methods


Method new()

Create a Title

Usage

Title$new(text, font_size = 72, color = WHITE, ...)

Arguments

text

Title text

font_size

Font size (default 72)

color

Color

...

Additional args


Method clone()

The objects of this class are cloneable with this method.

Usage

Title$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.