Skip to contents

Smoothly morphs a mobject into a target mobject by interpolating their Bezier control points (after matching curve counts).

Super class

manimR::Animation -> Transform

Public fields

target_mobject

The target shape to morph into

path_arc

Arc angle for the interpolation path (0 = straight)

Methods

Inherited methods


Method new()

Create a Transform animation

Usage

Transform$new(
  mobject,
  target_mobject,
  path_arc = 0,
  run_time = 1,
  rate_func = "smooth",
  ...
)

Arguments

mobject

Source mobject

target_mobject

Target mobject to morph into

path_arc

Arc angle for curved morph path (radians)

run_time

Duration

rate_func

Easing

...

Additional args


Method begin()

Save starting state and match curves

Usage

Transform$begin()


Method interpolate_mobject()

Interpolate between source and target

Usage

Transform$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method get_all_mobjects()

Get all involved mobjects

Usage

Transform$get_all_mobjects()


Method clone()

The objects of this class are cloneable with this method.

Usage

Transform$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.