Skip to contents

Transforms submobjects by matching them based on shape similarity. Unmatched submobjects fade in/out.

Super classes

manimR::Animation -> manimR::AnimationGroup -> TransformMatchingShapes

Methods

Inherited methods


Method new()

Create a TransformMatchingShapes animation

Usage

TransformMatchingShapes$new(
  source,
  target,
  run_time = 1,
  rate_func = "smooth",
  ...
)

Arguments

source

Source VGroup

target

Target VGroup

run_time

Duration

rate_func

Easing

...

Additional args


Method clone()

The objects of this class are cloneable with this method.

Usage

TransformMatchingShapes$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.