Skip to contents

Animation that calls a function on the mobject each frame.

Super class

manimR::Animation -> UpdateFromFunc

Public fields

update_func

Function(mobject) called each frame

Methods

Inherited methods


Method new()

Create an UpdateFromFunc animation

Usage

UpdateFromFunc$new(
  mobject,
  update_func,
  run_time = 1,
  rate_func = "linear",
  ...
)

Arguments

mobject

Mobject to update

update_func

Function(mobject) that modifies the mobject

run_time

Duration

rate_func

Easing

...

Additional args


Method interpolate_mobject()

Call update function

Usage

UpdateFromFunc$interpolate_mobject(alpha)

Arguments

alpha

Eased progress


Method clone()

The objects of this class are cloneable with this method.

Usage

UpdateFromFunc$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.