Skip to contents

Container specifically for VMobjects. Inherits from VMobject so it can be treated as a single drawable entity.

Super classes

manimR::MObject -> manimR::VMobject -> VGroup

Methods

Inherited methods


Method new()

Create a new VGroup

Usage

VGroup$new(...)

Arguments

...

VMobjects to include


Method add()

Add VMobjects

Usage

VGroup$add(...)

Arguments

...

VMobjects to add


Method remove()

Remove a VMobject

Usage

VGroup$remove(obj)

Arguments

obj

VMobject to remove


Method length()

Get number of objects

Usage

VGroup$length()


Method arrange()

Arrange children in a line

Usage

VGroup$arrange(direction = RIGHT, buff = MED_SMALL_BUFF, center = TRUE)

Arguments

direction

Direction

buff

Buffer between objects

center

Center the arrangement


Method arrange_in_grid()

Arrange in grid

Usage

VGroup$arrange_in_grid(n_cols = 3, buff = MED_SMALL_BUFF)

Arguments

n_cols

Number of columns

buff

Buffer


Method clone()

The objects of this class are cloneable with this method.

Usage

VGroup$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.