Skip to contents

An arrow starting from the origin (or a given point).

An arrow starting from the origin.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Line -> manimR::Arrow -> Vector

Methods

Public methods

Inherited methods


Method new()

Usage

Vector$new(direction = c(1, 0, 0), origin = c(0, 0, 0), ...)


Method clone()

The objects of this class are cloneable with this method.

Usage

Vector$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

manimR::MObject -> manimR::VMobject -> manimR::Line -> manimR::Arrow -> Vector

Methods

Public methods

Inherited methods


Method new()

Usage

Vector$new(direction = c(1, 0, 0), origin = c(0, 0, 0), ...)


Method clone()

The objects of this class are cloneable with this method.

Usage

Vector$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.