Skip to contents

A no-op animation that holds the scene for a duration.

Super class

manimR::Animation -> Wait

Methods

Inherited methods


Method new()

Create a Wait animation

Usage

Wait$new(run_time = 1)

Arguments

run_time

Duration to wait


Method interpolate_mobject()

No-op interpolation

Usage

Wait$interpolate_mobject(alpha)

Arguments

alpha

Progress (unused)


Method clone()

The objects of this class are cloneable with this method.

Usage

Wait$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.