Runs a simple benchmark comparing the performance of available backends.
Examples
if (FALSE) { # \dontrun{
results <- benchmark_backends()
print(results)
} # }
Runs a simple benchmark comparing the performance of available backends.
if (FALSE) { # \dontrun{
results <- benchmark_backends()
print(results)
} # }