Skip to contents

Factory function that creates the appropriate renderer based on the backend name. Falls back to ragg if the requested backend is unavailable.

Usage

create_renderer(
  backend = "ragg",
  width = 1280,
  height = 720,
  background_color = "#000000",
  camera = NULL
)

Arguments

backend

Backend name: "ragg", "svg", "grid"

width

Width in pixels

height

Height in pixels

background_color

Background color

camera

Optional Camera object

Value

An AbstractRenderer subclass instance