Returns TRUE if either C++ or Rust backend is available, meaning operations will be accelerated.
Examples
if (FALSE) { # \dontrun{
if (has_compiled_backend()) {
message("Using accelerated rendering!")
}
} # }
Returns TRUE if either C++ or Rust backend is available, meaning operations will be accelerated.
if (FALSE) { # \dontrun{
if (has_compiled_backend()) {
message("Using accelerated rendering!")
}
} # }