Create mathematical animations using a tidyverse-friendly grammar of motion. Inspired by Grant Sanderson's 'manim' library, manimR makes it as easy to create stunning mathematical visualizations as it is to create plots with 'ggplot2'. Features include LaTeX integration, data-driven animations, ggplot2 conversion, and a visual scene builder RStudio addin.
Author
Maintainer: Gio Author geofmanda@gmail.com [copyright holder]
Other contributors:
manimR contributors [contributor]