High-performance renderer using the Anti-Grain Geometry (Agg) library via the ragg package. Inherits from AbstractRenderer and implements the concrete rendering methods for raster output.
High-performance renderer using the Anti-Grain Geometry (Agg) library via the ragg package. Inherits from AbstractRenderer and implements the concrete rendering methods for raster output.