Animates the result of calling a method on a mobject. Creates a copy, applies the method, then morphs to the result.
Super classes
manimR::Animation -> manimR::Transform -> ApplyMethod
Methods
Inherited methods
manimR::Animation$copy()manimR::Animation$finish()manimR::Animation$interpolate()manimR::Animation$is_introducer()manimR::Animation$is_remover()manimR::Animation$print()manimR::Animation$to_anim_spec()manimR::Transform$begin()manimR::Transform$get_all_mobjects()manimR::Transform$interpolate_mobject()
Method new()
Create an ApplyMethod animation
Usage
ApplyMethod$new(mobject, method_name, ..., run_time = 1, rate_func = "smooth")