Grows an Arrow from its start point to its end.
Super class
manimR::Animation -> GrowArrow
Methods
Method new()
Create a GrowArrow animation
Usage
GrowArrow$new(arrow, run_time = 1, rate_func = "smooth", ...)Grows an Arrow from its start point to its end.
manimR::Animation -> GrowArrow
new()Create a GrowArrow animation
GrowArrow$new(arrow, run_time = 1, rate_func = "smooth", ...)