Grows a mobject from a single point at its center.
Super class
manimR::Animation -> GrowFromCenter
Methods
Method new()
Create a GrowFromCenter animation
Usage
GrowFromCenter$new(mobject, run_time = 1, rate_func = "smooth", ...)Grows a mobject from a single point at its center.
manimR::Animation -> GrowFromCenter
new()Create a GrowFromCenter animation
GrowFromCenter$new(mobject, run_time = 1, rate_func = "smooth", ...)