Moves a mobject along the path of another VMobject.
Super class
manimR::Animation -> MoveAlongPath
Methods
Method new()
Create a MoveAlongPath animation
Usage
MoveAlongPath$new(mobject, path, run_time = 2, rate_func = "linear", ...)Moves a mobject along the path of another VMobject.
manimR::Animation -> MoveAlongPath
new()Create a MoveAlongPath animation
MoveAlongPath$new(mobject, path, run_time = 2, rate_func = "linear", ...)