A Camera that can be animated. Provides the frame object (a VMobject
rectangle representing the camera's field of view) which can be animated
with standard Transform/ApplyMethod animations.
Super class
manimR::Camera -> MovingCamera
Methods
Method sync_from_frame()
Sync camera state from the frame mobject Call this after animating the frame to update the camera.
Method move_to()
Override move_to to also update frame
Method shift()
Override shift to also update frame