A no-op animation that holds the scene for a duration.
Methods
Inherited methods
Method new()
Create a Wait animation
Arguments
run_time
Duration to wait
Method interpolate_mobject()
No-op interpolation
Usage
Wait$interpolate_mobject(alpha)
Method clone()
The objects of this class are cloneable with this method.
Arguments
deep
Whether to make a deep clone.