A 2D coordinate system with x and y axes. Supports tick marks, axis labels, function plotting, area shading, and coordinate mapping.
Super classes
manimR::MObject -> manimR::VMobject -> Axes
Public fields
x_rangec(min, max, step) for x-axis
y_rangec(min, max, step) for y-axis
x_lengthWidth in scene units
y_lengthHeight in scene units
x_axisThe x-axis NumberLine
y_axisThe y-axis NumberLine
include_ticksInclude tick marks
include_numbersInclude number labels
tipsInclude arrow tips on axes
axis_configConfig list for both axes
Methods
Inherited methods
manimR::MObject$add_updater()manimR::MObject$align_to()manimR::MObject$clear_updaters()manimR::MObject$copy()manimR::MObject$generate_target()manimR::MObject$get_bottom()manimR::MObject$get_corner()manimR::MObject$get_height()manimR::MObject$get_left()manimR::MObject$get_right()manimR::MObject$get_top()manimR::MObject$get_width()manimR::MObject$match_color()manimR::MObject$next_to()manimR::MObject$set_opacity()manimR::MObject$to_corner()manimR::MObject$to_edge()manimR::VMobject$add()manimR::VMobject$add_cubic_bezier()manimR::VMobject$add_line()manimR::VMobject$add_submobject()manimR::VMobject$append_points()manimR::VMobject$clear_points()manimR::VMobject$get_all_points()manimR::VMobject$get_arc_length()manimR::VMobject$get_bounding_box()manimR::VMobject$get_center()manimR::VMobject$get_draw_points()manimR::VMobject$get_end()manimR::VMobject$get_num_curves()manimR::VMobject$get_points()manimR::VMobject$get_start()manimR::VMobject$get_submobject()manimR::VMobject$has_points()manimR::VMobject$move_to()manimR::VMobject$point_from_proportion()manimR::VMobject$print()manimR::VMobject$remove()manimR::VMobject$rotate()manimR::VMobject$scale()manimR::VMobject$set_color()manimR::VMobject$set_fill()manimR::VMobject$set_points()manimR::VMobject$set_stroke()manimR::VMobject$set_style()manimR::VMobject$shift()
Method plot()
Plot a function y = f(x) as a VMobject curve
Usage
Axes$plot(
func,
x_range = NULL,
color = YELLOW,
stroke_width = DEFAULT_STROKE_WIDTH,
num_points = 200
)Method get_area()
Get the area between a graph and the x-axis
Method plot_line_graph()
Plot a line graph from data vectors