Functions for selecting and configuring the computational backend (C++, Rust, or pure R) for manimR operations. The package automatically selects the best available backend, but users can override this choice.
Functions for selecting and configuring the computational backend (C++, Rust, or pure R) for manimR operations. The package automatically selects the best available backend, but users can override this choice.