Sets the computational backend to use for subsequent operations. If the requested backend is not available, falls back to the best available alternative with a warning.
Usage
set_backend(backend = c("auto", "cpp", "rust", "r"))Sets the computational backend to use for subsequent operations. If the requested backend is not available, falls back to the best available alternative with a warning.
set_backend(backend = c("auto", "cpp", "rust", "r"))