A table composed of cells arranged in rows and columns. Each cell contains a Text submobject. The table supports highlighting individual cells, rows, or columns with color, and individual cell animation.
Super classes
manimR::MObject -> manimR::VMobject -> Table
Public fields
dataMatrix or data.frame of table contents
col_namesColumn header names
row_namesRow header names
n_rowsNumber of data rows
n_colsNumber of columns
cell_widthWidth of each cell in scene units
cell_heightHeight of each cell
font_sizeFont size for cell text
header_font_sizeFont size for headers
line_colorColor of grid lines
header_colorHeader text color
cell_entriesMatrix-like list of Text mobjects (row x col)
h_linesVGroup of horizontal lines
v_linesVGroup of vertical lines
header_entriesList of header Text mobjects
Methods
Inherited methods
manimR::MObject$add_updater()manimR::MObject$align_to()manimR::MObject$clear_updaters()manimR::MObject$copy()manimR::MObject$generate_target()manimR::MObject$get_bottom()manimR::MObject$get_corner()manimR::MObject$get_height()manimR::MObject$get_left()manimR::MObject$get_right()manimR::MObject$get_top()manimR::MObject$get_width()manimR::MObject$match_color()manimR::MObject$next_to()manimR::MObject$set_opacity()manimR::MObject$to_corner()manimR::MObject$to_edge()manimR::VMobject$add()manimR::VMobject$add_cubic_bezier()manimR::VMobject$add_line()manimR::VMobject$add_submobject()manimR::VMobject$append_points()manimR::VMobject$clear_points()manimR::VMobject$get_all_points()manimR::VMobject$get_arc_length()manimR::VMobject$get_bounding_box()manimR::VMobject$get_center()manimR::VMobject$get_draw_points()manimR::VMobject$get_end()manimR::VMobject$get_num_curves()manimR::VMobject$get_points()manimR::VMobject$get_start()manimR::VMobject$get_submobject()manimR::VMobject$has_points()manimR::VMobject$move_to()manimR::VMobject$point_from_proportion()manimR::VMobject$print()manimR::VMobject$remove()manimR::VMobject$rotate()manimR::VMobject$scale()manimR::VMobject$set_color()manimR::VMobject$set_fill()manimR::VMobject$set_points()manimR::VMobject$set_stroke()manimR::VMobject$set_style()manimR::VMobject$shift()
Method new()
Create a Table
Usage
Table$new(
data,
col_names = NULL,
row_names = NULL,
cell_width = 1.5,
cell_height = 0.6,
font_size = 24,
header_font_size = 28,
line_color = WHITE,
header_color = YELLOW,
color = WHITE,
include_outer_lines = TRUE,
...
)Arguments
dataMatrix, data.frame, or list of row vectors
col_namesCharacter vector of column names (NULL = auto)
row_namesCharacter vector of row names (NULL = none)
cell_widthCell width
cell_heightCell height
font_sizeFont size for cells
header_font_sizeFont size for headers
line_colorGrid line color
header_colorHeader text color
colorDefault text color
include_outer_linesInclude border lines
...Additional args